==> massxpert3_10.4.0.orig.tar.gz: massxpert3-10.4.0/src/gui/MonomerCrossLinkDlg.hpp <==
/* BEGIN software license
 *
 * MsXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2026 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the MsXpertSuite project.
 *
 * The MsXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
 * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */

#pragma once

/////////////////////// stdlib includes


/////////////////////// Qt includes
#include <QMainWindow>


/////////////////////// pappsomspp includes


/////////////////////// libXpertMass includes


/////////////////////// libXpertMassGui includes


/////////////////////// Local includes
#include "ui_MonomerCrossLinkDlg.h"
#include "AbstractSeqEdWndDependentDlg.hpp"
#include "SequenceEditorWnd.hpp"


namespace MsXpS
{
namespace MassXpert
{


class Monomer;


class MonomerCrossLinkDlg : public AbstractSeqEdWndDependentDlg
{
  Q_OBJECT
  public:
  MonomerCrossLinkDlg(SequenceEditorWnd *editorWnd,
                      /* no polymer **/
                      /* no libXpertMassCore::PolChemDef **/
                      const QString &settings_file_path,
                      const QString &application_name,
                      const QString &description);

  ~MonomerCrossLinkDlg();

  public slots:
  void crossLink();
  void uncrossLink();

  void crossLinkerListWidgetItemSelectionChanged();

  void crossLinkedMonomerListWidgetItemSelectionChanged();
  void crossLinkedMonomerListWidgetItemActivated(QListWidgetItem *);

  void crossLinkListWidgetItemSelectionChanged();
  void crossLinkListWidgetItemActivated(QListWidgetItem *);

  void displayAllCrossLinksChanged(int);
  void crossLinkChangedSlot(libXpertMassCore::Polymer *polymer_p);

  void polymerSequenceModifiedSlot();

  private:
  Ui::MonomerCrossLinkDlg m_ui;

  bool m_polymerSequenceModified = false;

  QColor m_crossLinkColor;
  int m_crossLinkPixelSize;

  bool populateAvailableCrossLinkerList();
  bool populateListOfCrossLinkedMonomers();
  bool populateListOfCrossLinks(bool all = true);

  std::vector<libXpertMassCore::MonomerSPtr> parseTargetMonomerPositionsString();

  bool initialize();

  void readSettings();
  void writeSettings();
};


} // namespace MassXpert
} // namespace MsXpS

==> massxpert_7.0.0.orig.tar.gz: massxpert-7.0.0/src/gui/MonomerCrossLinkDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef MONOMER_CROSS_LINK_DLG_HPP
#define MONOMER_CROSS_LINK_DLG_HPP


/////////////////////// Qt includes
#include <QMainWindow>


/////////////////////// Local includes
#include "ui_MonomerCrossLinkDlg.h"
#include "AbstractSeqEdWndDependentDlg.hpp"
#include "SequenceEditorWnd.hpp"


namespace msxps
{

	namespace massxpert
	{



class Monomer;


class MonomerCrossLinkDlg : public AbstractSeqEdWndDependentDlg
{
  Q_OBJECT

  private:
  Ui::MonomerCrossLinkDlg m_ui;

  bool m_polymerSequenceModified = false;

  QColor m_crossLinkColor;
  int m_crossLinkPixelSize;

  bool populateCrossLinkerList();
  bool populateCrossLinkedMonomerList();
  bool populateCrossLinkList(bool = true);

  bool parseTargetMonomerString(QList<const Monomer *> *);

  bool initialize();

  void readSettings();
  void writeSettings();

  public:
  MonomerCrossLinkDlg(SequenceEditorWnd *editorWnd,
                      /* no polymer **/
                      /* no PolChemDef **/
                      const QString &settingsFilePath);

  ~MonomerCrossLinkDlg();

  public slots:
  void crossLink();
  void uncrossLink();

  void crossLinkerListWidgetItemSelectionChanged();

  void crossLinkedMonomerListWidgetItemSelectionChanged();
  void crossLinkedMonomerListWidgetItemActivated(QListWidgetItem *);

  void crossLinkListWidgetItemSelectionChanged();
  void crossLinkListWidgetItemActivated(QListWidgetItem *);

  void displayAllCrossLinksChanged(int);
  void crossLinkChangedSlot(Polymer *);

  void polymerSequenceModifiedSlot();
};

} // namespace massxpert

} // namespace msxps


#endif // MONOMER_CROSS_LINK_DLG_HPP
